roles

package
v0.10.3-0...-b44ade8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: Apache-2.0 Imports: 42 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

all milvus related metrics is in a separate registry

Functions

This section is empty.

Types

type MilvusRoles

type MilvusRoles struct {
	EnableProxy         bool `env:"ENABLE_PROXY"`
	EnableMixCoord      bool `env:"ENABLE_ROOT_COORD"`
	EnableQueryNode     bool `env:"ENABLE_QUERY_NODE"`
	EnableDataNode      bool `env:"ENABLE_DATA_NODE"`
	EnableStreamingNode bool `env:"ENABLE_STREAMING_NODE"`
	EnableRootCoord     bool `env:"ENABLE_ROOT_COORD"`
	EnableQueryCoord    bool `env:"ENABLE_QUERY_COORD"`
	EnableDataCoord     bool `env:"ENABLE_DATA_COORD"`
	EnableCDC           bool `env:"ENABLE_CDC"`
	Local               bool
	Alias               string
	Embedded            bool

	ServerType string
	// contains filtered or unexported fields
}

MilvusRoles decides which components are brought up with Milvus.

func NewMilvusRoles

func NewMilvusRoles() *MilvusRoles

NewMilvusRoles creates a new MilvusRoles with private fields initialized.

func (*MilvusRoles) GetRoles

func (mr *MilvusRoles) GetRoles() []string

func (*MilvusRoles) Run

func (mr *MilvusRoles) Run()

Run Milvus components.

Jump to